SunmiStyle class

SunmiStyle

Blueprint class to cluster print parameters, avoiding the need to execute 3 distinct statements to modify layout metrics.

Constructors

SunmiStyle({SunmiFontSize? fontSize, SunmiPrintAlign? align, bool? bold})
Instantiates a structural layout style instance template.
const

Properties

align SunmiPrintAlign?
Layout horizon align direction policy indicator.
final
bold bool?
Text formatting configuration weight option parameter.
final
fontSize SunmiFontSize?
Font scaling dimension metric flag configuration.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited